<?php
namespace App\Controller\Admin;
use App\Controller\Admin\Component\ImgComponent;

use App\Controller\Admin\AppController;
use Cake\Event\Event;
use Cake\ORM\TableRegistry;
use Cake\Core\Configure;
use Cake\I18n\Time;
use Cake\View\Helper\TimeHelper;
use Cake\Datasource\ConnectionManager;
/******************************************************************************
*File Name:	 Controller
*Creation Date: [11-02-2016]
*Modification Date: [11-02-2016]
*Author: [Raushan Suri]
*Author: [Modified By Raushan Suri]
*Description: [This controller consist of function related to Department.]
******************************************************************************/
class BookingsController extends AppController
{

    public function beforeFilter(Event $event)
    {
        parent::beforeFilter($event);
        $this->Auth->allow(['showprofile']);
    }

    
    /********************************************************************************
	Function Name: index
	*Type: Public function used as action of the controller
	*Input: No input
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to view all member list and search.
	*********************************************************************************/
    public function index($id=null)
    {
        $layoutTitle = 'Labor Dispatch :: Manage Booking';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
        $limit = 30;//Configure::read('App.adminPageLimit');
        
		$this->loadModel('Users');
		$DList = $this->Users->find('list', ['keyField' => 'id', 'valueField' => ['fullName', 'email']])
						->where(['Users.role'=>'Driver'])
                        ->order(['Users.fullName'=>'ASC'])->toArray();
		$driverList = str_replace(";"," - ",$DList);
		
        $this->paginate = [
            'limit' => $limit,
            'order' => ['Bookings.created' => 'DESC'],
			'contain' =>['Users','Vendors','Categories']
        ];        
        $keyword = $this->request->query('keyword');
		$driverid = $this->request->query('driverid');
		$Status = $this->request->query('status');
		$startDate = $this->request->query('startDate');
		$endDate = $this->request->query('endDate');
		$condition[] = '';
		if($Status != ''){
			$condition[] = ['Bookings.status'=>$Status];
		}
		if($driverid !=''){
			$condition[] = ['Bookings.vendorId'=>$driverid,'Bookings.status IN'=>[1,2]];
		}
		
		if($startDate != ''){
			//$startDate = $startDate." 00:00:01" ;
			$condition[] = ['Bookings.bookingDate >='=> $startDate];
        }
        if($endDate != ''){
			//$endDate = $endDate." 23:59:59";
			$condition[] = ['Bookings.bookingDate <='=> $endDate];
        }
		
        if($keyword != ''){
			$condition[] = [
				'OR' => [
					["Bookings.address LIKE '%".$keyword."%'"],
					["Bookings.couponCode LIKE '%".$keyword."%'"],
					["Bookings.bookingDate LIKE '%".$keyword."%'"],
					["Bookings.transactionId LIKE '%".$keyword."%'"],
					["Bookings.totalAmount LIKE '%".$keyword."%'"],
					["Bookings.vendorType LIKE '%".$keyword."%'"],
					["Bookings.discountAmount LIKE '%".$keyword."%'"],
					["Bookings.TIP LIKE '%".$keyword."%'"],
					["Users.email LIKE '%".$keyword."%'"],
					["Users.fullName LIKE '%".$keyword."%'"],
					["Vendors.email LIKE '%".$keyword."%'"],
					["Vendors.fullName LIKE '%".$keyword."%'"],
					["Categories.name LIKE '%".$keyword."%'"],
				]				
			];
		}        
        $query = $this->Bookings->find('all')->where($condition);       
        $bookings = $this->paginate($query);
        $bookings = $bookings->toArray();
		//pr($bookings);die;
        $this->set(compact('bookings', 'limit', 'driverList'));
    }
	
	
	/********************************************************************************
	Function Name: index
	*Type: Public function used as action of the controller
	*Input: No input
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to view all member list and search.
	*********************************************************************************/
    public function nowbooking($id=null)
    {
        $layoutTitle = 'Labor Dispatch :: Manage Booking';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
        $limit = 30;//Configure::read('App.adminPageLimit');
        
        $this->paginate = [
            'limit' => $limit,
            'order' => ['Bookings.created' => 'DESC'],
			'contain' =>['Users','Vendors']
        ];        
        $keyword = $this->request->query('keyword');
		$Status = $this->request->query('status');
		$condition[] = ['Bookings.bookingDate' => date('Y-m-d')];
		if($Status != ''){
			$condition[] = ['Bookings.status'=>$Status];
		}
        if($keyword != ''){
			$condition[] = [
				'OR' => [
					["Bookings.address LIKE '%".$keyword."%'"],
					["Bookings.couponCode LIKE '%".$keyword."%'"],
					["Bookings.bookingDate LIKE '%".$keyword."%'"],
					["Bookings.transactionId LIKE '%".$keyword."%'"],
					["Bookings.totalAmount LIKE '%".$keyword."%'"],
					["Bookings.vendorType LIKE '%".$keyword."%'"],
					["Bookings.discountAmount LIKE '%".$keyword."%'"],
					["Bookings.TIP LIKE '%".$keyword."%'"],
					["Users.email LIKE '%".$keyword."%'"],
					["Users.fullName LIKE '%".$keyword."%'"],
					["Vendors.email LIKE '%".$keyword."%'"],
					["Vendors.fullName LIKE '%".$keyword."%'"],
					["Categories.name LIKE '%".$keyword."%'"],
				]				
			];
		}        
        $query = $this->Bookings->find('all')->where($condition);       
        $bookings = $this->paginate($query);
        $bookings = $bookings->toArray();
		//pr($bookings);die;
        $this->set(compact('bookings', 'limit'));
    }

      
    /********************************************************************************
	Function Name: add
	*Type: Public function used as action of the controller
	*Input: No input
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to add hours.
	*********************************************************************************/
    public function add()
    {
        $layoutTitle = 'Labor Dispatch ::  Add New Booking';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
		$this->loadModel('Users');
		$this->loadModel('Categories');
		$userList = $this->Users->find('list', ['keyField' => 'id', 'valueField' => ['fullName', 'email']])
						->where(['Users.role'=>'Member'])
                        ->order(['Users.fullName'=>'ASC'])->toArray();
		$userList = str_replace(";", " - ", $userList);
		$vendorList = $this->Users->find('list', ['keyField' => 'id', 'valueField' => ['fullName', 'email']])
						->where(['Users.role'=>'Partner'])
                        ->order(['Users.fullName'=>'ASC'])->toArray();
		$vendorList = str_replace(";", " - ", $vendorList);
		
		$categoriesList = $this->Categories->find('all')->where(['Categories.parentId'=>'0'])->contain(['Subcategories'])->order(['Categories.name'=>'ASC'])->toArray();
		
		$option = '<option value="">Choose One</option>';
		foreach($categoriesList as $value){
			if(@$value->subcategories){
				$option .= '<optgroup label="'.$value->name.'">';
				foreach($value->subcategories as $sub){
					$option .= '<option value="'.$sub->id.'">'.$sub->name.'</option>';
				}
				$option .= '</optgroup>';
			}else{
				$option .=  '<option value="'.$value->id.'">'.$value->name.'</option>';
			}
		}
		//pr($option); die;	
        $bookings = $this->Bookings->newEntity();        
       
        if ($this->request->is('post')) {
            
			$bookings = $this->Bookings->patchEntity($bookings, $this->request->data, ['validate' => 'customer']);            
			$bookings['created'] = date('Y-m-d H:i:s');
			$bookings['created'] = date('Y-m-d', strtotime($this->request->data['bookingDate']));
			//$path = WWW_ROOT . 'img/uploads/feature/original/';
			if ($this->Bookings->save($bookings)) {
				$this->Flash->success(__('Booking added successfully.'));
				return $this->redirect(['action' => 'index']);	
			}else{
				//pr($users);die;
				$this->Flash->error(__('Unable to add new booking, Please try again later.'));
			}
		}
        $this->set(compact('bookings','userList', 'vendorList', 'option'));
    }
    
    
    
    
    /********************************************************************************
	Function Name: edit
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to edit hours.
	*********************************************************************************/
    public function edit($id)
    {
        $layoutTitle = 'Labor Dispatch :: Edit Booking';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
        
		$this->loadModel('Users');
		$this->loadModel('Categories');
		$userList = $this->Users->find('list', ['keyField' => 'id', 'valueField' => ['fullName', 'email']])
						->where(['Users.role'=>'Member'])
                        ->order(['Users.fullName'=>'ASC'])->toArray();
		$userList = str_replace(";", " - ", $userList);
		$vendorList = $this->Users->find('list', ['keyField' => 'id', 'valueField' => ['fullName', 'email']])
						->where(['Users.role'=>'Partner'])
                        ->order(['Users.fullName'=>'ASC'])->toArray();
		$vendorList = str_replace(";", " - ", $vendorList);
		
		$categoriesList = $this->Categories->find('all')->where(['Categories.parentId'=>'0'])->contain(['Subcategories'])->order(['Categories.name'=>'ASC'])->toArray();
		
		$option = '<option value="">Choose One</option>';
		foreach($categoriesList as $value){
			if(@$value->subcategories){
				$option .= '<optgroup label="'.$value->name.'">';
				foreach($value->subcategories as $sub){
					$option .= '<option value="'.$sub->id.'">'.$sub->name.'</option>';
				}
				$option .= '</optgroup>';
			}else{
				$option .=  '<option value="'.$value->id.'">'.$value->name.'</option>';
			}
		}
		
        $bookings = $this->Bookings->find()->where(['Bookings.id' => $id])->first();//fields name in contain[] with coma
        if ($this->request->is(['patch', 'post', 'put'])) {
			
			$bookings = $this->Bookings->patchEntity($bookings, $this->request->data, ['validate' => 'customer']);
			$bookings['created'] = date('Y-m-d', strtotime($this->request->data['bookingDate']));
			
			$path = WWW_ROOT . 'img/uploads/feature/original/';
			if ($this->Bookings->save($bookings)) {
				
				$this->Flash->success(__('The booking updated successfully.'));
                return $this->redirect(['action' => 'index']);
			} else {
				
				$this->Flash->error(__('Booking information could not be saved. Please try again later.'));
			}
        }
        $this->set(compact('bookings','userList', 'vendorList', 'option'));
    }
    
    
    /********************************************************************************
	Function Name: delete
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to delete hours permanently.
	*********************************************************************************/
    public function delete($id = null)
    {
        $users = $this->Bookings->get($id);
        if ($this->Bookings->delete($users)) {
            $this->Flash->success(__('Booking has been deleted.'));
        } else {
            $this->Flash->error(__('Booking could not be deleted. Please, try again.'));
        }
        return $this->redirect(['controller' => 'Bookings', 'action' => 'index']);
    }
    
    
    /********************************************************************************
	Function Name: status
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to update hours status.
	*********************************************************************************/
    public function status($id){
		$users = $this->Bookings->get($id);
		$status = '1';
		$msg = 'activated';
		if($users->status == '1'){
			$status = '0';
			$msg = 'deactivated';
		}
		
		$articles = TableRegistry::get('Bookings');
		$query = $articles->query();
		$query->update()
			->set(['status' => $status])
			->where(['id' => $id])
			->execute();
		$this->Flash->success(__('Booking has been '.$msg.' successfully.'));
		return $this->redirect(['controller' => 'Bookings', 'action' => 'index']);
	}
    
    
    /********************************************************************************
	Function Name: details
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to view hours information.
	*********************************************************************************/
    public function details($id){
        $layoutTitle = 'Labor Dispatch ::  Member Details';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');        
		$users = $this->Bookings->find()->where(['Bookings.id' => $id])->contain(['Users','Vendors','Categories'])->first();
        if(!empty($users)){
			//pr($users); die;
            $this->set(compact('users'));
        }else{
            $this->Flash->error(__('Booking does not exist.'));
            return $this->redirect(['controller' => 'Bookings', 'action' => 'index']);
        }
	}
	
	
}