<?php
namespace App\Controller\Admin;
use App\Controller\Admin\Component\ImgComponent;

use App\Controller\Admin\AppController;
use Cake\Event\Event;
use Cake\ORM\TableRegistry;
use Cake\Core\Configure;
use Cake\I18n\Time;
use Cake\View\Helper\TimeHelper;
use Cake\Datasource\ConnectionManager;
/******************************************************************************
*File Name:	 Controller
*Creation Date: [11-02-2016]
*Modification Date: [11-02-2016]
*Author: [Raushan Suri]
*Author: [Modified By Raushan Suri]
*Description: [This controller consist of function related to Department.]
******************************************************************************/
class LearningsController extends AppController
{

    public function beforeFilter(Event $event)
    {
        parent::beforeFilter($event);
        $this->Auth->allow(['showprofile']);
    }

    
    /********************************************************************************
	Function Name: index
	*Type: Public function used as action of the controller
	*Input: No input
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to view all member list and search.
	*********************************************************************************/
    public function index($id=null)
    {
        $layoutTitle = 'Labor Dispatch :: Manage Learning';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
        $limit = 30;//Configure::read('App.adminPageLimit');
        
        $this->paginate = [
            'limit' => $limit,
            'order' => [
                'Learnings.created' => 'DESC'
            ],
        ];        
        $keyword = $this->request->query('keyword');
		$condition = [];
        if($keyword != ''){
			$condition = [
				'OR' => [
					["Learnings.name LIKE '%".$keyword."%'"],
					["Learnings.description LIKE '%".$keyword."%'"],
				]				
			];
		}        
        $query = $this->Learnings->find('all')->where($condition);       
        $learnings = $this->paginate($query);
        $learnings = $learnings->toArray();
		//pr($learnings);die;
        $this->set(compact('learnings', 'limit'));
    }

      
    /********************************************************************************
	Function Name: add
	*Type: Public function used as action of the controller
	*Input: No input
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to add hours.
	*********************************************************************************/
    public function add()
    {
        $layoutTitle = 'Labor Dispatch ::  Add New Learning';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
		
		
        $learnings = $this->Learnings->newEntity();        
       
        if ($this->request->is('post')) {
            
			$lerningImage = $this->request->data['image'];	
			unset($this->request->data['image']);			
			if(!empty($lerningImage['name'])){
				$find = array(" ","'",'"');
				$replace = array("","","");
				$filename = time().str_replace($find,$replace,$lerningImage['name']);
				$this->request->data['image'] = $filename;
			}
			$learningVideo = $this->request->data['video'];	
			unset($this->request->data['video']);			
			if(!empty($learningVideo['name'])){
				$find = array(" ","'",'"');
				$replace = array("","","");
				$filename2 = time().str_replace($find,$replace,$learningVideo['name']);
				$this->request->data['video'] = $filename2;
			}
				
			$learnings = $this->Learnings->patchEntity($learnings, $this->request->data, ['validate' => 'customer']);            
			$learnings['created'] = date('Y-m-d H:i:s');
			//$path = WWW_ROOT . 'img/uploads/feature/original/';
			if ($this->Learnings->save($learnings)) {
				if (!empty($lerningImage) && $lerningImage['name'] != '') {
					$path = WWW_ROOT . 'img/uploads/learning/';	                    
					move_uploaded_file($lerningImage['tmp_name'], $path.$filename);
					@chmod($path.$filename, 0777);
				}
				if (!empty($learningVideo) && $learningVideo['name'] != '') {
					$path = WWW_ROOT . 'img/uploads/learning/';	                    
					move_uploaded_file($learningVideo['tmp_name'], $path.$filename2);
					@chmod($path.$filename2, 0777);
				}
				$this->Flash->success(__('Learning added successfully.'));
				return $this->redirect(['action' => 'index']);	
			}else{
				//pr($users);die;
				$this->Flash->error(__('Unable to add new learning, Please try again later.'));
			}
		}
        $this->set(compact('learnings','client_list'));
    }
    
    
    
    
    /********************************************************************************
	Function Name: edit
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to edit hours.
	*********************************************************************************/
    public function edit($id)
    {
        $layoutTitle = 'Labor Dispatch :: Edit Learning';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
        
        $learnings = $this->Learnings->find()->where(['Learnings.id' => $id])->first();//fields name in contain[] with coma
        if ($this->request->is(['patch', 'post', 'put'])) {
			
			$lerningImage = $this->request->data['image'];	
			unset($this->request->data['image']);
			$old_data = $this->Learnings->get($id);            			
			if(!empty($lerningImage['name'])){
				$find = array(" ","'",'"');
				$replace = array("","","");
				$filename = time().str_replace($find,$replace,$lerningImage['name']);
				$this->request->data['image'] = $filename;
			}	
			$lerningVideo = $this->request->data['video'];	
			unset($this->request->data['video']);
			if(!empty($lerningVideo['name'])){
				$find = array(" ","'",'"');
				$replace = array("","","");
				$filename2 = time().str_replace($find,$replace,$lerningVideo['name']);
				$this->request->data['video'] = $filename2;
			}	
			
			$learnings = $this->Learnings->patchEntity($learnings, $this->request->data, ['validate' => 'customer']);
			
			if(!empty($filename)){				
				$oldfilename = $old_data->image;
			}
			if(!empty($filename2)){				
				$oldfilename2 = $old_data->video;
			}
			
			$path = WWW_ROOT . 'img/uploads/learning/';
			if ($this->Learnings->save($learnings)) {
				if (!empty($lerningImage) && $lerningImage['name'] != '') {
					$path = WWW_ROOT . 'img/uploads/learning/';	
					@unlink(WWW_ROOT . 'img/uploads/learning/'.$oldfilename);
					move_uploaded_file($lerningImage['tmp_name'], $path.$filename);
					@chmod($path.$filename, 0777);
				}
				
				if (!empty($lerningVideo) && $lerningVideo['name'] != '') {
					$path = WWW_ROOT . 'img/uploads/learning/';	
					@unlink(WWW_ROOT . 'img/uploads/learning/'.$oldfilename2);
					move_uploaded_file($lerningVideo['tmp_name'], $path.$filename2);
					@chmod($path.$filename2, 0777);
				}
				$this->Flash->success(__('The learning updated successfully.'));
                return $this->redirect(['action' => 'index']);
			} else {
				
				$this->Flash->error(__('Learning information could not be saved. Please try again later.'));
			}
        }
        $this->set(compact('learnings'));
    }
    
    
    /********************************************************************************
	Function Name: delete
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to delete hours permanently.
	*********************************************************************************/
    public function delete($id = null)
    {
        $users = $this->Learnings->get($id);
        if ($this->Learnings->delete($users)) {
            $this->Flash->success(__('Learning has been deleted.'));
        } else {
            $this->Flash->error(__('Learning could not be deleted. Please, try again.'));
        }
        return $this->redirect(['controller' => 'Learnings', 'action' => 'index']);
    }
    
    
    /********************************************************************************
	Function Name: status
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to update hours status.
	*********************************************************************************/
    public function status($id){
		$users = $this->Learnings->get($id);
		$status = '1';
		$msg = 'activated';
		if($users->status == '1'){
			$status = '0';
			$msg = 'deactivated';
		}
		
		$articles = TableRegistry::get('Learnings');
		$query = $articles->query();
		$query->update()
			->set(['status' => $status])
			->where(['id' => $id])
			->execute();
		$this->Flash->success(__('Learning has been '.$msg.' successfully.'));
		return $this->redirect(['controller' => 'Learnings', 'action' => 'index']);
	}
    
    
    /********************************************************************************
	Function Name: details
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to view hours information.
	*********************************************************************************/
    public function details($id){
        $layoutTitle = 'Labor Dispatch ::  Member Details';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');        
		$users = $this->Learnings->find()->where(['Learnings.id' => $id])->first();
        if(!empty($users)){
            $this->set(compact('users'));
        }else{
            $this->Flash->error(__('Member doesnot exist.'));
            return $this->redirect(['controller' => 'Learnings', 'action' => 'index']);
        }
	}
	
	
}